@@ -125,7 +125,7 @@ PHP_METHOD(Phalcon_Di_Service_Builder, build) {
 
 	ZEPHIR_OBS_VAR(&className);
 	if (UNEXPECTED(!(zephir_array_isset_string_fetch(&className, &definition, SL("className"), 0)))) {
-		ZEPHIR_THROW_EXCEPTION_DEBUG_STR(phalcon_di_exception_ce, "Invalid service definition. Missing 'className' parameter", "/home/nikos/Work/niden/cphalcon/phalcon/Di/Service/Builder.zep", 41);
+		ZEPHIR_THROW_EXCEPTION_DEBUG_STR(phalcon_di_exception_ce, "Invalid service definition. Missing 'className' parameter", "phalcon/Di/Service/Builder.zep", 41);
 		return;
 	}
 	if (Z_TYPE_P(parameters) == IS_ARRAY) {
@@ -141,7 +141,7 @@ PHP_METHOD(Phalcon_Di_Service_Builder, build) {
 	} else {
 		ZEPHIR_OBS_VAR(&arguments);
 		if (zephir_array_isset_string_fetch(&arguments, &definition, SL("arguments"), 0)) {
-			ZEPHIR_CALL_METHOD(&_0$$8, this_ptr, "buildparameters", NULL, 225, container, &arguments);
+			ZEPHIR_CALL_METHOD(&_0$$8, this_ptr, "buildparameters", NULL, 242, container, &arguments);
 			zephir_check_call_status();
 			ZEPHIR_INIT_NVAR(&instance);
 			ZEPHIR_LAST_CALL_STATUS = zephir_create_instance_params(&instance, &className, &_0$$8);
@@ -155,14 +155,14 @@ PHP_METHOD(Phalcon_Di_Service_Builder, build) {
 	ZEPHIR_OBS_VAR(&paramCalls);
 	if (zephir_array_isset_string_fetch(&paramCalls, &definition, SL("calls"), 0)) {
 		if (UNEXPECTED(Z_TYPE_P(&instance) != IS_OBJECT)) {
-			ZEPHIR_THROW_EXCEPTION_DEBUG_STR(phalcon_di_exception_ce, "The definition has setter injection parameters but the constructor didn't return an instance", "/home/nikos/Work/niden/cphalcon/phalcon/Di/Service/Builder.zep", 83);
+			ZEPHIR_THROW_EXCEPTION_DEBUG_STR(phalcon_di_exception_ce, "The definition has setter injection parameters but the constructor didn't return an instance", "phalcon/Di/Service/Builder.zep", 83);
 			return;
 		}
 		if (UNEXPECTED(Z_TYPE_P(&paramCalls) != IS_ARRAY)) {
-			ZEPHIR_THROW_EXCEPTION_DEBUG_STR(phalcon_di_exception_ce, "Setter injection parameters must be an array", "/home/nikos/Work/niden/cphalcon/phalcon/Di/Service/Builder.zep", 89);
+			ZEPHIR_THROW_EXCEPTION_DEBUG_STR(phalcon_di_exception_ce, "Setter injection parameters must be an array", "phalcon/Di/Service/Builder.zep", 89);
 			return;
 		}
-		zephir_is_iterable(&paramCalls, 0, "/home/nikos/Work/niden/cphalcon/phalcon/Di/Service/Builder.zep", 148);
+		zephir_is_iterable(&paramCalls, 0, "phalcon/Di/Service/Builder.zep", 148);
 		if (Z_TYPE_P(&paramCalls) == IS_ARRAY) {
 			ZEND_HASH_FOREACH_KEY_VAL(Z_ARRVAL_P(&paramCalls), _3$$10, _4$$10, _1$$10)
 			{
@@ -179,9 +179,9 @@ PHP_METHOD(Phalcon_Di_Service_Builder, build) {
 					object_init_ex(&_5$$14, phalcon_di_exception_ce);
 					ZEPHIR_INIT_NVAR(&_6$$14);
 					ZEPHIR_CONCAT_SV(&_6$$14, "Method call must be an array on position ", &methodPosition);
-					ZEPHIR_CALL_METHOD(NULL, &_5$$14, "__construct", &_7, 6, &_6$$14);
+					ZEPHIR_CALL_METHOD(NULL, &_5$$14, "__construct", &_7, 8, &_6$$14);
 					zephir_check_call_status();
-					zephir_throw_exception_debug(&_5$$14, "/home/nikos/Work/niden/cphalcon/phalcon/Di/Service/Builder.zep", 103);
+					zephir_throw_exception_debug(&_5$$14, "phalcon/Di/Service/Builder.zep", 103);
 					ZEPHIR_MM_RESTORE();
 					return;
 				}
@@ -191,9 +191,9 @@ PHP_METHOD(Phalcon_Di_Service_Builder, build) {
 					object_init_ex(&_8$$15, phalcon_di_exception_ce);
 					ZEPHIR_INIT_NVAR(&_9$$15);
 					ZEPHIR_CONCAT_SV(&_9$$15, "The method name is required on position ", &methodPosition);
-					ZEPHIR_CALL_METHOD(NULL, &_8$$15, "__construct", &_7, 6, &_9$$15);
+					ZEPHIR_CALL_METHOD(NULL, &_8$$15, "__construct", &_7, 8, &_9$$15);
 					zephir_check_call_status();
-					zephir_throw_exception_debug(&_8$$15, "/home/nikos/Work/niden/cphalcon/phalcon/Di/Service/Builder.zep", 112);
+					zephir_throw_exception_debug(&_8$$15, "phalcon/Di/Service/Builder.zep", 112);
 					ZEPHIR_MM_RESTORE();
 					return;
 				}
@@ -208,15 +208,15 @@ PHP_METHOD(Phalcon_Di_Service_Builder, build) {
 						object_init_ex(&_10$$17, phalcon_di_exception_ce);
 						ZEPHIR_INIT_NVAR(&_11$$17);
 						ZEPHIR_CONCAT_SV(&_11$$17, "Call arguments must be an array ", &methodPosition);
-						ZEPHIR_CALL_METHOD(NULL, &_10$$17, "__construct", &_7, 6, &_11$$17);
+						ZEPHIR_CALL_METHOD(NULL, &_10$$17, "__construct", &_7, 8, &_11$$17);
 						zephir_check_call_status();
-						zephir_throw_exception_debug(&_10$$17, "/home/nikos/Work/niden/cphalcon/phalcon/Di/Service/Builder.zep", 124);
+						zephir_throw_exception_debug(&_10$$17, "phalcon/Di/Service/Builder.zep", 124);
 						ZEPHIR_MM_RESTORE();
 						return;
 					}
 					if (zephir_fast_count_int(&arguments)) {
 						ZEPHIR_INIT_NVAR(&_12$$18);
-						ZEPHIR_CALL_METHOD(&_13$$18, this_ptr, "buildparameters", NULL, 225, container, &arguments);
+						ZEPHIR_CALL_METHOD(&_13$$18, this_ptr, "buildparameters", NULL, 242, container, &arguments);
 						zephir_check_call_status();
 						ZEPHIR_CALL_USER_FUNC_ARRAY(&_12$$18, &methodCall, &_13$$18);
 						zephir_check_call_status();
@@ -245,9 +245,9 @@ PHP_METHOD(Phalcon_Di_Service_Builder, build) {
 						object_init_ex(&_15$$20, phalcon_di_exception_ce);
 						ZEPHIR_INIT_NVAR(&_16$$20);
 						ZEPHIR_CONCAT_SV(&_16$$20, "Method call must be an array on position ", &methodPosition);
-						ZEPHIR_CALL_METHOD(NULL, &_15$$20, "__construct", &_7, 6, &_16$$20);
+						ZEPHIR_CALL_METHOD(NULL, &_15$$20, "__construct", &_7, 8, &_16$$20);
 						zephir_check_call_status();
-						zephir_throw_exception_debug(&_15$$20, "/home/nikos/Work/niden/cphalcon/phalcon/Di/Service/Builder.zep", 103);
+						zephir_throw_exception_debug(&_15$$20, "phalcon/Di/Service/Builder.zep", 103);
 						ZEPHIR_MM_RESTORE();
 						return;
 					}
@@ -257,9 +257,9 @@ PHP_METHOD(Phalcon_Di_Service_Builder, build) {
 						object_init_ex(&_17$$21, phalcon_di_exception_ce);
 						ZEPHIR_INIT_NVAR(&_18$$21);
 						ZEPHIR_CONCAT_SV(&_18$$21, "The method name is required on position ", &methodPosition);
-						ZEPHIR_CALL_METHOD(NULL, &_17$$21, "__construct", &_7, 6, &_18$$21);
+						ZEPHIR_CALL_METHOD(NULL, &_17$$21, "__construct", &_7, 8, &_18$$21);
 						zephir_check_call_status();
-						zephir_throw_exception_debug(&_17$$21, "/home/nikos/Work/niden/cphalcon/phalcon/Di/Service/Builder.zep", 112);
+						zephir_throw_exception_debug(&_17$$21, "phalcon/Di/Service/Builder.zep", 112);
 						ZEPHIR_MM_RESTORE();
 						return;
 					}
@@ -275,15 +275,15 @@ PHP_METHOD(Phalcon_Di_Service_Builder, build) {
 							object_init_ex(&_20$$23, phalcon_di_exception_ce);
 							ZEPHIR_INIT_NVAR(&_21$$23);
 							ZEPHIR_CONCAT_SV(&_21$$23, "Call arguments must be an array ", &methodPosition);
-							ZEPHIR_CALL_METHOD(NULL, &_20$$23, "__construct", &_7, 6, &_21$$23);
+							ZEPHIR_CALL_METHOD(NULL, &_20$$23, "__construct", &_7, 8, &_21$$23);
 							zephir_check_call_status();
-							zephir_throw_exception_debug(&_20$$23, "/home/nikos/Work/niden/cphalcon/phalcon/Di/Service/Builder.zep", 124);
+							zephir_throw_exception_debug(&_20$$23, "phalcon/Di/Service/Builder.zep", 124);
 							ZEPHIR_MM_RESTORE();
 							return;
 						}
 						if (zephir_fast_count_int(&arguments)) {
 							ZEPHIR_INIT_NVAR(&_22$$24);
-							ZEPHIR_CALL_METHOD(&_23$$24, this_ptr, "buildparameters", NULL, 225, container, &arguments);
+							ZEPHIR_CALL_METHOD(&_23$$24, this_ptr, "buildparameters", NULL, 242, container, &arguments);
 							zephir_check_call_status();
 							ZEPHIR_CALL_USER_FUNC_ARRAY(&_22$$24, &methodCall, &_23$$24);
 							zephir_check_call_status();
@@ -303,14 +303,14 @@ PHP_METHOD(Phalcon_Di_Service_Builder, build) {
 	ZEPHIR_OBS_NVAR(&paramCalls);
 	if (zephir_array_isset_string_fetch(&paramCalls, &definition, SL("properties"), 0)) {
 		if (UNEXPECTED(Z_TYPE_P(&instance) != IS_OBJECT)) {
-			ZEPHIR_THROW_EXCEPTION_DEBUG_STR(phalcon_di_exception_ce, "The definition has properties injection parameters but the constructor didn't return an instance", "/home/nikos/Work/niden/cphalcon/phalcon/Di/Service/Builder.zep", 158);
+			ZEPHIR_THROW_EXCEPTION_DEBUG_STR(phalcon_di_exception_ce, "The definition has properties injection parameters but the constructor didn't return an instance", "phalcon/Di/Service/Builder.zep", 158);
 			return;
 		}
 		if (UNEXPECTED(Z_TYPE_P(&paramCalls) != IS_ARRAY)) {
-			ZEPHIR_THROW_EXCEPTION_DEBUG_STR(phalcon_di_exception_ce, "Setter injection parameters must be an array", "/home/nikos/Work/niden/cphalcon/phalcon/Di/Service/Builder.zep", 164);
+			ZEPHIR_THROW_EXCEPTION_DEBUG_STR(phalcon_di_exception_ce, "Setter injection parameters must be an array", "phalcon/Di/Service/Builder.zep", 164);
 			return;
 		}
-		zephir_is_iterable(&paramCalls, 0, "/home/nikos/Work/niden/cphalcon/phalcon/Di/Service/Builder.zep", 208);
+		zephir_is_iterable(&paramCalls, 0, "phalcon/Di/Service/Builder.zep", 208);
 		if (Z_TYPE_P(&paramCalls) == IS_ARRAY) {
 			ZEND_HASH_FOREACH_KEY_VAL(Z_ARRVAL_P(&paramCalls), _27$$25, _28$$25, _25$$25)
 			{
@@ -327,9 +327,9 @@ PHP_METHOD(Phalcon_Di_Service_Builder, build) {
 					object_init_ex(&_29$$29, phalcon_di_exception_ce);
 					ZEPHIR_INIT_NVAR(&_30$$29);
 					ZEPHIR_CONCAT_SV(&_30$$29, "Property must be an array on position ", &propertyPosition);
-					ZEPHIR_CALL_METHOD(NULL, &_29$$29, "__construct", &_7, 6, &_30$$29);
+					ZEPHIR_CALL_METHOD(NULL, &_29$$29, "__construct", &_7, 8, &_30$$29);
 					zephir_check_call_status();
-					zephir_throw_exception_debug(&_29$$29, "/home/nikos/Work/niden/cphalcon/phalcon/Di/Service/Builder.zep", 178);
+					zephir_throw_exception_debug(&_29$$29, "phalcon/Di/Service/Builder.zep", 178);
 					ZEPHIR_MM_RESTORE();
 					return;
 				}
@@ -339,9 +339,9 @@ PHP_METHOD(Phalcon_Di_Service_Builder, build) {
 					object_init_ex(&_31$$30, phalcon_di_exception_ce);
 					ZEPHIR_INIT_NVAR(&_32$$30);
 					ZEPHIR_CONCAT_SV(&_32$$30, "The property name is required on position ", &propertyPosition);
-					ZEPHIR_CALL_METHOD(NULL, &_31$$30, "__construct", &_7, 6, &_32$$30);
+					ZEPHIR_CALL_METHOD(NULL, &_31$$30, "__construct", &_7, 8, &_32$$30);
 					zephir_check_call_status();
-					zephir_throw_exception_debug(&_31$$30, "/home/nikos/Work/niden/cphalcon/phalcon/Di/Service/Builder.zep", 187);
+					zephir_throw_exception_debug(&_31$$30, "phalcon/Di/Service/Builder.zep", 187);
 					ZEPHIR_MM_RESTORE();
 					return;
 				}
@@ -351,13 +351,13 @@ PHP_METHOD(Phalcon_Di_Service_Builder, build) {
 					object_init_ex(&_33$$31, phalcon_di_exception_ce);
 					ZEPHIR_INIT_NVAR(&_34$$31);
 					ZEPHIR_CONCAT_SV(&_34$$31, "The property value is required on position ", &propertyPosition);
-					ZEPHIR_CALL_METHOD(NULL, &_33$$31, "__construct", &_7, 6, &_34$$31);
+					ZEPHIR_CALL_METHOD(NULL, &_33$$31, "__construct", &_7, 8, &_34$$31);
 					zephir_check_call_status();
-					zephir_throw_exception_debug(&_33$$31, "/home/nikos/Work/niden/cphalcon/phalcon/Di/Service/Builder.zep", 196);
+					zephir_throw_exception_debug(&_33$$31, "phalcon/Di/Service/Builder.zep", 196);
 					ZEPHIR_MM_RESTORE();
 					return;
 				}
-				ZEPHIR_CALL_METHOD(&_35$$28, this_ptr, "buildparameter", &_36, 226, container, &propertyPosition, &propertyValue);
+				ZEPHIR_CALL_METHOD(&_35$$28, this_ptr, "buildparameter", &_36, 243, container, &propertyPosition, &propertyValue);
 				zephir_check_call_status();
 				zephir_update_property_zval_zval(&instance, &propertyName, &_35$$28);
 			} ZEND_HASH_FOREACH_END();
@@ -379,9 +379,9 @@ PHP_METHOD(Phalcon_Di_Service_Builder, build) {
 						object_init_ex(&_37$$33, phalcon_di_exception_ce);
 						ZEPHIR_INIT_NVAR(&_38$$33);
 						ZEPHIR_CONCAT_SV(&_38$$33, "Property must be an array on position ", &propertyPosition);
-						ZEPHIR_CALL_METHOD(NULL, &_37$$33, "__construct", &_7, 6, &_38$$33);
+						ZEPHIR_CALL_METHOD(NULL, &_37$$33, "__construct", &_7, 8, &_38$$33);
 						zephir_check_call_status();
-						zephir_throw_exception_debug(&_37$$33, "/home/nikos/Work/niden/cphalcon/phalcon/Di/Service/Builder.zep", 178);
+						zephir_throw_exception_debug(&_37$$33, "phalcon/Di/Service/Builder.zep", 178);
 						ZEPHIR_MM_RESTORE();
 						return;
 					}
@@ -391,9 +391,9 @@ PHP_METHOD(Phalcon_Di_Service_Builder, build) {
 						object_init_ex(&_39$$34, phalcon_di_exception_ce);
 						ZEPHIR_INIT_NVAR(&_40$$34);
 						ZEPHIR_CONCAT_SV(&_40$$34, "The property name is required on position ", &propertyPosition);
-						ZEPHIR_CALL_METHOD(NULL, &_39$$34, "__construct", &_7, 6, &_40$$34);
+						ZEPHIR_CALL_METHOD(NULL, &_39$$34, "__construct", &_7, 8, &_40$$34);
 						zephir_check_call_status();
-						zephir_throw_exception_debug(&_39$$34, "/home/nikos/Work/niden/cphalcon/phalcon/Di/Service/Builder.zep", 187);
+						zephir_throw_exception_debug(&_39$$34, "phalcon/Di/Service/Builder.zep", 187);
 						ZEPHIR_MM_RESTORE();
 						return;
 					}
@@ -403,13 +403,13 @@ PHP_METHOD(Phalcon_Di_Service_Builder, build) {
 						object_init_ex(&_41$$35, phalcon_di_exception_ce);
 						ZEPHIR_INIT_NVAR(&_42$$35);
 						ZEPHIR_CONCAT_SV(&_42$$35, "The property value is required on position ", &propertyPosition);
-						ZEPHIR_CALL_METHOD(NULL, &_41$$35, "__construct", &_7, 6, &_42$$35);
+						ZEPHIR_CALL_METHOD(NULL, &_41$$35, "__construct", &_7, 8, &_42$$35);
 						zephir_check_call_status();
-						zephir_throw_exception_debug(&_41$$35, "/home/nikos/Work/niden/cphalcon/phalcon/Di/Service/Builder.zep", 196);
+						zephir_throw_exception_debug(&_41$$35, "phalcon/Di/Service/Builder.zep", 196);
 						ZEPHIR_MM_RESTORE();
 						return;
 					}
-					ZEPHIR_CALL_METHOD(&_43$$32, this_ptr, "buildparameter", &_36, 226, container, &propertyPosition, &propertyValue);
+					ZEPHIR_CALL_METHOD(&_43$$32, this_ptr, "buildparameter", &_36, 243, container, &propertyPosition, &propertyValue);
 					zephir_check_call_status();
 					zephir_update_property_zval_zval(&instance, &propertyName, &_43$$32);
 				ZEPHIR_CALL_METHOD(NULL, &paramCalls, "next", NULL, 0);
@@ -474,9 +474,9 @@ PHP_METHOD(Phalcon_Di_Service_Builder, buildParameter) {
 		ZVAL_LONG(&_1$$3, position);
 		ZEPHIR_INIT_VAR(&_2$$3);
 		ZEPHIR_CONCAT_SVS(&_2$$3, "Argument at position ", &_1$$3, " must have a type");
-		ZEPHIR_CALL_METHOD(NULL, &_0$$3, "__construct", NULL, 6, &_2$$3);
+		ZEPHIR_CALL_METHOD(NULL, &_0$$3, "__construct", NULL, 8, &_2$$3);
 		zephir_check_call_status();
-		zephir_throw_exception_debug(&_0$$3, "/home/nikos/Work/niden/cphalcon/phalcon/Di/Service/Builder.zep", 228);
+		zephir_throw_exception_debug(&_0$$3, "phalcon/Di/Service/Builder.zep", 228);
 		ZEPHIR_MM_RESTORE();
 		return;
 	}
@@ -490,14 +490,14 @@ PHP_METHOD(Phalcon_Di_Service_Builder, buildParameter) {
 				ZVAL_LONG(&_4$$5, position);
 				ZEPHIR_INIT_VAR(&_5$$5);
 				ZEPHIR_CONCAT_SV(&_5$$5, "Service 'name' is required in parameter on position ", &_4$$5);
-				ZEPHIR_CALL_METHOD(NULL, &_3$$5, "__construct", NULL, 6, &_5$$5);
+				ZEPHIR_CALL_METHOD(NULL, &_3$$5, "__construct", NULL, 8, &_5$$5);
 				zephir_check_call_status();
-				zephir_throw_exception_debug(&_3$$5, "/home/nikos/Work/niden/cphalcon/phalcon/Di/Service/Builder.zep", 241);
+				zephir_throw_exception_debug(&_3$$5, "phalcon/Di/Service/Builder.zep", 241);
 				ZEPHIR_MM_RESTORE();
 				return;
 			}
 			if (UNEXPECTED(Z_TYPE_P(container) != IS_OBJECT)) {
-				ZEPHIR_THROW_EXCEPTION_DEBUG_STR(phalcon_di_exception_ce, "The dependency injector container is not valid", "/home/nikos/Work/niden/cphalcon/phalcon/Di/Service/Builder.zep", 247);
+				ZEPHIR_THROW_EXCEPTION_DEBUG_STR(phalcon_di_exception_ce, "The dependency injector container is not valid", "phalcon/Di/Service/Builder.zep", 247);
 				return;
 			}
 			ZEPHIR_RETURN_CALL_METHOD(container, "get", NULL, 0, &name);
@@ -513,9 +513,9 @@ PHP_METHOD(Phalcon_Di_Service_Builder, buildParameter) {
 				ZVAL_LONG(&_7$$8, position);
 				ZEPHIR_INIT_VAR(&_8$$8);
 				ZEPHIR_CONCAT_SV(&_8$$8, "Service 'value' is required in parameter on position ", &_7$$8);
-				ZEPHIR_CALL_METHOD(NULL, &_6$$8, "__construct", NULL, 6, &_8$$8);
+				ZEPHIR_CALL_METHOD(NULL, &_6$$8, "__construct", NULL, 8, &_8$$8);
 				zephir_check_call_status();
-				zephir_throw_exception_debug(&_6$$8, "/home/nikos/Work/niden/cphalcon/phalcon/Di/Service/Builder.zep", 259);
+				zephir_throw_exception_debug(&_6$$8, "phalcon/Di/Service/Builder.zep", 259);
 				ZEPHIR_MM_RESTORE();
 				return;
 			}
@@ -530,14 +530,14 @@ PHP_METHOD(Phalcon_Di_Service_Builder, buildParameter) {
 				ZVAL_LONG(&_10$$10, position);
 				ZEPHIR_INIT_VAR(&_11$$10);
 				ZEPHIR_CONCAT_SV(&_11$$10, "Service 'className' is required in parameter on position ", &_10$$10);
-				ZEPHIR_CALL_METHOD(NULL, &_9$$10, "__construct", NULL, 6, &_11$$10);
+				ZEPHIR_CALL_METHOD(NULL, &_9$$10, "__construct", NULL, 8, &_11$$10);
 				zephir_check_call_status();
-				zephir_throw_exception_debug(&_9$$10, "/home/nikos/Work/niden/cphalcon/phalcon/Di/Service/Builder.zep", 272);
+				zephir_throw_exception_debug(&_9$$10, "phalcon/Di/Service/Builder.zep", 272);
 				ZEPHIR_MM_RESTORE();
 				return;
 			}
 			if (UNEXPECTED(Z_TYPE_P(container) != IS_OBJECT)) {
-				ZEPHIR_THROW_EXCEPTION_DEBUG_STR(phalcon_di_exception_ce, "The dependency injector container is not valid", "/home/nikos/Work/niden/cphalcon/phalcon/Di/Service/Builder.zep", 278);
+				ZEPHIR_THROW_EXCEPTION_DEBUG_STR(phalcon_di_exception_ce, "The dependency injector container is not valid", "phalcon/Di/Service/Builder.zep", 278);
 				return;
 			}
 			ZEPHIR_OBS_VAR(&instanceArguments);
@@ -556,9 +556,9 @@ PHP_METHOD(Phalcon_Di_Service_Builder, buildParameter) {
 		ZVAL_LONG(&_13$$13, position);
 		ZEPHIR_INIT_VAR(&_14$$13);
 		ZEPHIR_CONCAT_SV(&_14$$13, "Unknown service type in parameter on position ", &_13$$13);
-		ZEPHIR_CALL_METHOD(NULL, &_12$$13, "__construct", NULL, 6, &_14$$13);
+		ZEPHIR_CALL_METHOD(NULL, &_12$$13, "__construct", NULL, 8, &_14$$13);
 		zephir_check_call_status();
-		zephir_throw_exception_debug(&_12$$13, "/home/nikos/Work/niden/cphalcon/phalcon/Di/Service/Builder.zep", 300);
+		zephir_throw_exception_debug(&_12$$13, "phalcon/Di/Service/Builder.zep", 300);
 		ZEPHIR_MM_RESTORE();
 		return;
 	} while(0);
@@ -598,7 +598,7 @@ PHP_METHOD(Phalcon_Di_Service_Builder, buildParameters) {
 
 	ZEPHIR_INIT_VAR(&buildArguments);
 	array_init(&buildArguments);
-	zephir_is_iterable(&arguments, 0, "/home/nikos/Work/niden/cphalcon/phalcon/Di/Service/Builder.zep", 322);
+	zephir_is_iterable(&arguments, 0, "phalcon/Di/Service/Builder.zep", 322);
 	if (Z_TYPE_P(&arguments) == IS_ARRAY) {
 		ZEND_HASH_FOREACH_KEY_VAL(Z_ARRVAL_P(&arguments), _2, _3, _0)
 		{
@@ -610,9 +610,9 @@ PHP_METHOD(Phalcon_Di_Service_Builder, buildParameters) {
 			}
 			ZEPHIR_INIT_NVAR(&argument);
 			ZVAL_COPY(&argument, _0);
-			ZEPHIR_CALL_METHOD(&_4$$3, this_ptr, "buildparameter", &_5, 226, container, &position, &argument);
+			ZEPHIR_CALL_METHOD(&_4$$3, this_ptr, "buildparameter", &_5, 243, container, &position, &argument);
 			zephir_check_call_status();
-			zephir_array_append(&buildArguments, &_4$$3, PH_SEPARATE, "/home/nikos/Work/niden/cphalcon/phalcon/Di/Service/Builder.zep", 319);
+			zephir_array_append(&buildArguments, &_4$$3, PH_SEPARATE, "phalcon/Di/Service/Builder.zep", 319);
 		} ZEND_HASH_FOREACH_END();
 	} else {
 		ZEPHIR_CALL_METHOD(NULL, &arguments, "rewind", NULL, 0);
@@ -627,9 +627,9 @@ PHP_METHOD(Phalcon_Di_Service_Builder, buildParameters) {
 			zephir_check_call_status();
 			ZEPHIR_CALL_METHOD(&argument, &arguments, "current", NULL, 0);
 			zephir_check_call_status();
-				ZEPHIR_CALL_METHOD(&_6$$4, this_ptr, "buildparameter", &_5, 226, container, &position, &argument);
+				ZEPHIR_CALL_METHOD(&_6$$4, this_ptr, "buildparameter", &_5, 243, container, &position, &argument);
 				zephir_check_call_status();
-				zephir_array_append(&buildArguments, &_6$$4, PH_SEPARATE, "/home/nikos/Work/niden/cphalcon/phalcon/Di/Service/Builder.zep", 319);
+				zephir_array_append(&buildArguments, &_6$$4, PH_SEPARATE, "phalcon/Di/Service/Builder.zep", 319);
 			ZEPHIR_CALL_METHOD(NULL, &arguments, "next", NULL, 0);
 			zephir_check_call_status();
 		}
