@@ -6,7 +6,11 @@ ZEPHIR_INIT_CLASS(Phalcon_Kernel);
 PHP_METHOD(Phalcon_Kernel, preComputeHashKey);
 
 ZEND_BEGIN_ARG_INFO_EX(arginfo_phalcon_kernel_precomputehashkey, 0, 0, 1)
+#if PHP_VERSION_ID >= 70200
+	ZEND_ARG_TYPE_INFO(0, key, IS_STRING, 0)
+#else
 	ZEND_ARG_INFO(0, key)
+#endif
 ZEND_END_ARG_INFO()
 
 ZEPHIR_INIT_FUNCS(phalcon_kernel_method_entry) {
