@@ -12,6 +12,14 @@
 #include "kernel/main.h"
 
 
+/**
+ * This file is part of the Phalcon Framework.
+ *
+ * (c) Phalcon Team <team@phalcon.io>
+ *
+ * For the full copyright and license information, please view the LICENSE.txt
+ * file that was distributed with this source code.
+ */
 /**
  * Phalcon\Mvc\DispatcherInterface
  *
@@ -21,25 +29,15 @@ ZEPHIR_INIT_CLASS(Phalcon_Mvc_DispatcherInterface) {
 
 	ZEPHIR_REGISTER_INTERFACE(Phalcon\\Mvc, DispatcherInterface, phalcon, mvc_dispatcherinterface, phalcon_mvc_dispatcherinterface_method_entry);
 
-	zend_class_implements(phalcon_mvc_dispatcherinterface_ce TSRMLS_CC, 1, phalcon_dispatcherinterface_ce);
+	zend_class_implements(phalcon_mvc_dispatcherinterface_ce, 1, phalcon_dispatcher_dispatcherinterface_ce);
 	return SUCCESS;
 
 }
 
 /**
- * Sets the default controller suffix
+ * Returns the active controller in the dispatcher
  */
-ZEPHIR_DOC_METHOD(Phalcon_Mvc_DispatcherInterface, setControllerSuffix);
-
-/**
- * Sets the default controller name
- */
-ZEPHIR_DOC_METHOD(Phalcon_Mvc_DispatcherInterface, setDefaultController);
-
-/**
- * Sets the controller name to be dispatched
- */
-ZEPHIR_DOC_METHOD(Phalcon_Mvc_DispatcherInterface, setControllerName);
+ZEPHIR_DOC_METHOD(Phalcon_Mvc_DispatcherInterface, getActiveController);
 
 /**
  * Gets last dispatched controller name
@@ -52,7 +50,17 @@ ZEPHIR_DOC_METHOD(Phalcon_Mvc_DispatcherInterface, getControllerName);
 ZEPHIR_DOC_METHOD(Phalcon_Mvc_DispatcherInterface, getLastController);
 
 /**
- * Returns the active controller in the dispatcher
+ * Sets the default controller suffix
  */
-ZEPHIR_DOC_METHOD(Phalcon_Mvc_DispatcherInterface, getActiveController);
+ZEPHIR_DOC_METHOD(Phalcon_Mvc_DispatcherInterface, setControllerSuffix);
+
+/**
+ * Sets the controller name to be dispatched
+ */
+ZEPHIR_DOC_METHOD(Phalcon_Mvc_DispatcherInterface, setControllerName);
+
+/**
+ * Sets the default controller name
+ */
+ZEPHIR_DOC_METHOD(Phalcon_Mvc_DispatcherInterface, setDefaultController);
 
