@@ -249,7 +249,7 @@ PHP_METHOD(Phalcon_Mvc_Micro, error) {
 
 
 
-	zephir_update_property_zval(this_ptr, SL("errorHandler"), handler);
+	zephir_update_property_zval(this_ptr, ZEND_STRL("errorHandler"), handler);
 	RETURN_THISW();
 
 }
@@ -349,7 +349,7 @@ PHP_METHOD(Phalcon_Mvc_Micro, getBoundModels) {
 
 	ZEPHIR_MM_GROW();
 
-	zephir_read_property(&_0, this_ptr, SL("modelBinder"), PH_NOISY_CC | PH_READONLY);
+	zephir_read_property(&_0, this_ptr, ZEND_STRL("modelBinder"), PH_NOISY_CC | PH_READONLY);
 	ZEPHIR_CPY_WRT(&modelBinder, &_0);
 	if (Z_TYPE_P(&modelBinder) == IS_NULL) {
 		array_init(return_value);
@@ -387,7 +387,7 @@ PHP_METHOD(Phalcon_Mvc_Micro, setEventsManager) {
 
 
 
-	zephir_update_property_zval(this_ptr, SL("eventsManager"), eventsManager);
+	zephir_update_property_zval(this_ptr, ZEND_STRL("eventsManager"), eventsManager);
 
 }
 
@@ -446,7 +446,7 @@ PHP_METHOD(Phalcon_Mvc_Micro, getRouter) {
 
 	ZEPHIR_MM_GROW();
 
-	zephir_read_property(&_0, this_ptr, SL("router"), PH_NOISY_CC | PH_READONLY);
+	zephir_read_property(&_0, this_ptr, ZEND_STRL("router"), PH_NOISY_CC | PH_READONLY);
 	ZEPHIR_CPY_WRT(&router, &_0);
 	if (Z_TYPE_P(&router) != IS_OBJECT) {
 		ZEPHIR_INIT_VAR(&_1$$3);
@@ -458,7 +458,7 @@ PHP_METHOD(Phalcon_Mvc_Micro, getRouter) {
 		ZVAL_BOOL(&_2$$3, 1);
 		ZEPHIR_CALL_METHOD(NULL, &router, "removeextraslashes", NULL, 0, &_2$$3);
 		zephir_check_call_status();
-		zephir_update_property_zval(this_ptr, SL("router"), &router);
+		zephir_update_property_zval(this_ptr, ZEND_STRL("router"), &router);
 	}
 	RETURN_CCTOR(&router);
 
@@ -496,16 +496,16 @@ PHP_METHOD(Phalcon_Mvc_Micro, getService) {
 	}
 
 
-	zephir_read_property(&_0, this_ptr, SL("container"), PH_NOISY_CC | PH_READONLY);
+	zephir_read_property(&_0, this_ptr, ZEND_STRL("container"), PH_NOISY_CC | PH_READONLY);
 	ZEPHIR_CPY_WRT(&container, &_0);
 	if (Z_TYPE_P(&container) != IS_OBJECT) {
 		ZEPHIR_INIT_NVAR(&container);
 		object_init_ex(&container, phalcon_di_factorydefault_ce);
-		ZEPHIR_CALL_METHOD(NULL, &container, "__construct", NULL, 420);
+		ZEPHIR_CALL_METHOD(NULL, &container, "__construct", NULL, 440);
 		zephir_check_call_status();
-		zephir_update_property_zval(this_ptr, SL("container"), &container);
+		zephir_update_property_zval(this_ptr, ZEND_STRL("container"), &container);
 	}
-	ZEPHIR_RETURN_CALL_METHOD(&container, "get", NULL, 421, &serviceName);
+	ZEPHIR_RETURN_CALL_METHOD(&container, "get", NULL, 441, &serviceName);
 	zephir_check_call_status();
 	RETURN_MM();
 
@@ -543,16 +543,16 @@ PHP_METHOD(Phalcon_Mvc_Micro, getSharedService) {
 	}
 
 
-	zephir_read_property(&_0, this_ptr, SL("container"), PH_NOISY_CC | PH_READONLY);
+	zephir_read_property(&_0, this_ptr, ZEND_STRL("container"), PH_NOISY_CC | PH_READONLY);
 	ZEPHIR_CPY_WRT(&container, &_0);
 	if (Z_TYPE_P(&container) != IS_OBJECT) {
 		ZEPHIR_INIT_NVAR(&container);
 		object_init_ex(&container, phalcon_di_factorydefault_ce);
-		ZEPHIR_CALL_METHOD(NULL, &container, "__construct", NULL, 420);
+		ZEPHIR_CALL_METHOD(NULL, &container, "__construct", NULL, 440);
 		zephir_check_call_status();
-		zephir_update_property_zval(this_ptr, SL("container"), &container);
+		zephir_update_property_zval(this_ptr, ZEND_STRL("container"), &container);
 	}
-	ZEPHIR_RETURN_CALL_METHOD(&container, "getshared", NULL, 422, &serviceName);
+	ZEPHIR_RETURN_CALL_METHOD(&container, "getshared", NULL, 442, &serviceName);
 	zephir_check_call_status();
 	RETURN_MM();
 
@@ -697,7 +697,7 @@ PHP_METHOD(Phalcon_Mvc_Micro, handle) {
 	ZVAL_NULL(&status);
 	ZEPHIR_INIT_VAR(&realHandler);
 	ZVAL_NULL(&realHandler);
-	zephir_read_property(&_0, this_ptr, SL("container"), PH_NOISY_CC | PH_READONLY);
+	zephir_read_property(&_0, this_ptr, ZEND_STRL("container"), PH_NOISY_CC | PH_READONLY);
 	ZEPHIR_CPY_WRT(&container, &_0);
 	if (UNEXPECTED(Z_TYPE_P(&container) != IS_OBJECT)) {
 		ZEPHIR_INIT_VAR(&_1$$3);
@@ -706,9 +706,9 @@ PHP_METHOD(Phalcon_Mvc_Micro, handle) {
 		ZVAL_STRING(&_4$$3, "micro services");
 		ZEPHIR_CALL_CE_STATIC(&_2$$3, phalcon_mvc_micro_exception_ce, "containerservicenotfound", &_3, 0, &_4$$3);
 		zephir_check_call_status();
-		ZEPHIR_CALL_METHOD(NULL, &_1$$3, "__construct", NULL, 6, &_2$$3);
+		ZEPHIR_CALL_METHOD(NULL, &_1$$3, "__construct", NULL, 8, &_2$$3);
 		zephir_check_call_status();
-		zephir_throw_exception_debug(&_1$$3, "/home/nikos/Work/niden/cphalcon/phalcon/Mvc/Micro.zep", 374);
+		zephir_throw_exception_debug(&_1$$3, "phalcon/Mvc/Micro.zep", 374);
 		ZEPHIR_MM_RESTORE();
 		return;
 	}
@@ -717,7 +717,7 @@ PHP_METHOD(Phalcon_Mvc_Micro, handle) {
 
 		ZEPHIR_INIT_VAR(&returnedValue);
 		ZVAL_NULL(&returnedValue);
-		zephir_read_property(&_5$$4, this_ptr, SL("eventsManager"), PH_NOISY_CC | PH_READONLY);
+		zephir_read_property(&_5$$4, this_ptr, ZEND_STRL("eventsManager"), PH_NOISY_CC | PH_READONLY);
 		ZEPHIR_CPY_WRT(&eventsManager, &_5$$4);
 		if (Z_TYPE_P(&eventsManager) == IS_OBJECT) {
 			ZEPHIR_INIT_VAR(&_7$$5);
@@ -739,7 +739,7 @@ PHP_METHOD(Phalcon_Mvc_Micro, handle) {
 		zephir_check_call_status_or_jump(try_end_1);
 		if (Z_TYPE_P(&matchedRoute) == IS_OBJECT) {
 			ZEPHIR_OBS_VAR(&handler);
-			zephir_read_property(&_10$$7, this_ptr, SL("handlers"), PH_NOISY_CC | PH_READONLY);
+			zephir_read_property(&_10$$7, this_ptr, ZEND_STRL("handlers"), PH_NOISY_CC | PH_READONLY);
 			ZEPHIR_CALL_METHOD(&_11$$7, &matchedRoute, "getrouteid", NULL, 0);
 			zephir_check_call_status_or_jump(try_end_1);
 			if (UNEXPECTED(!(zephir_array_isset_fetch(&handler, &_10$$7, &_11$$7, 0)))) {
@@ -747,13 +747,13 @@ PHP_METHOD(Phalcon_Mvc_Micro, handle) {
 				object_init_ex(&_12$$8, phalcon_mvc_micro_exception_ce);
 				ZEPHIR_INIT_VAR(&_13$$8);
 				ZVAL_STRING(&_13$$8, "Matched route doesn't have an associated handler");
-				ZEPHIR_CALL_METHOD(NULL, &_12$$8, "__construct", NULL, 6, &_13$$8);
+				ZEPHIR_CALL_METHOD(NULL, &_12$$8, "__construct", NULL, 8, &_13$$8);
 				zephir_check_call_status_or_jump(try_end_1);
-				zephir_throw_exception_debug(&_12$$8, "/home/nikos/Work/niden/cphalcon/phalcon/Mvc/Micro.zep", 410);
+				zephir_throw_exception_debug(&_12$$8, "phalcon/Mvc/Micro.zep", 410);
 				goto try_end_1;
 
 			}
-			zephir_update_property_zval(this_ptr, SL("activeHandler"), &handler);
+			zephir_update_property_zval(this_ptr, ZEND_STRL("activeHandler"), &handler);
 			if (Z_TYPE_P(&eventsManager) == IS_OBJECT) {
 				ZEPHIR_INIT_VAR(&_15$$9);
 				ZVAL_STRING(&_15$$9, "micro:beforeExecuteRoute");
@@ -763,16 +763,16 @@ PHP_METHOD(Phalcon_Mvc_Micro, handle) {
 					RETURN_MM_BOOL(0);
 				}
 				ZEPHIR_OBS_NVAR(&handler);
-				zephir_read_property(&handler, this_ptr, SL("activeHandler"), PH_NOISY_CC);
+				zephir_read_property(&handler, this_ptr, ZEND_STRL("activeHandler"), PH_NOISY_CC);
 			}
-			zephir_read_property(&_16$$7, this_ptr, SL("beforeHandlers"), PH_NOISY_CC | PH_READONLY);
+			zephir_read_property(&_16$$7, this_ptr, ZEND_STRL("beforeHandlers"), PH_NOISY_CC | PH_READONLY);
 			ZEPHIR_CPY_WRT(&beforeHandlers, &_16$$7);
 			if (0) {
-				zephir_update_property_zval(this_ptr, SL("stopped"), &__$true);
+				zephir_update_property_zval(this_ptr, ZEND_STRL("stopped"), &__$true);
 			} else {
-				zephir_update_property_zval(this_ptr, SL("stopped"), &__$false);
+				zephir_update_property_zval(this_ptr, ZEND_STRL("stopped"), &__$false);
 			}
-			zephir_is_iterable(&beforeHandlers, 0, "/home/nikos/Work/niden/cphalcon/phalcon/Mvc/Micro.zep", 463);
+			zephir_is_iterable(&beforeHandlers, 0, "phalcon/Mvc/Micro.zep", 463);
 			if (Z_TYPE_P(&beforeHandlers) == IS_ARRAY) {
 				ZEND_HASH_FOREACH_VAL(Z_ARRVAL_P(&beforeHandlers), _17$$7)
 				{
@@ -791,9 +791,9 @@ PHP_METHOD(Phalcon_Mvc_Micro, handle) {
 							object_init_ex(&_20$$14, phalcon_mvc_micro_exception_ce);
 							ZEPHIR_INIT_NVAR(&_21$$14);
 							ZVAL_STRING(&_21$$14, "'before' handler is not callable");
-							ZEPHIR_CALL_METHOD(NULL, &_20$$14, "__construct", NULL, 6, &_21$$14);
+							ZEPHIR_CALL_METHOD(NULL, &_20$$14, "__construct", NULL, 8, &_21$$14);
 							zephir_check_call_status_or_jump(try_end_1);
-							zephir_throw_exception_debug(&_20$$14, "/home/nikos/Work/niden/cphalcon/phalcon/Mvc/Micro.zep", 446);
+							zephir_throw_exception_debug(&_20$$14, "phalcon/Mvc/Micro.zep", 446);
 							goto try_end_1;
 
 						}
@@ -801,7 +801,7 @@ PHP_METHOD(Phalcon_Mvc_Micro, handle) {
 						ZEPHIR_CALL_USER_FUNC(&status, &before);
 						zephir_check_call_status_or_jump(try_end_1);
 					}
-					zephir_read_property(&_22$$11, this_ptr, SL("stopped"), PH_NOISY_CC | PH_READONLY);
+					zephir_read_property(&_22$$11, this_ptr, ZEND_STRL("stopped"), PH_NOISY_CC | PH_READONLY);
 					if (zephir_is_true(&_22$$11)) {
 						RETURN_CCTOR(&status);
 					}
@@ -830,9 +830,9 @@ PHP_METHOD(Phalcon_Mvc_Micro, handle) {
 								object_init_ex(&_24$$19, phalcon_mvc_micro_exception_ce);
 								ZEPHIR_INIT_NVAR(&_25$$19);
 								ZVAL_STRING(&_25$$19, "'before' handler is not callable");
-								ZEPHIR_CALL_METHOD(NULL, &_24$$19, "__construct", NULL, 6, &_25$$19);
+								ZEPHIR_CALL_METHOD(NULL, &_24$$19, "__construct", NULL, 8, &_25$$19);
 								zephir_check_call_status_or_jump(try_end_1);
-								zephir_throw_exception_debug(&_24$$19, "/home/nikos/Work/niden/cphalcon/phalcon/Mvc/Micro.zep", 446);
+								zephir_throw_exception_debug(&_24$$19, "phalcon/Mvc/Micro.zep", 446);
 								goto try_end_1;
 
 							}
@@ -840,7 +840,7 @@ PHP_METHOD(Phalcon_Mvc_Micro, handle) {
 							ZEPHIR_CALL_USER_FUNC(&status, &before);
 							zephir_check_call_status_or_jump(try_end_1);
 						}
-						zephir_read_property(&_26$$16, this_ptr, SL("stopped"), PH_NOISY_CC | PH_READONLY);
+						zephir_read_property(&_26$$16, this_ptr, ZEND_STRL("stopped"), PH_NOISY_CC | PH_READONLY);
 						if (zephir_is_true(&_26$$16)) {
 							RETURN_CCTOR(&status);
 						}
@@ -851,7 +851,7 @@ PHP_METHOD(Phalcon_Mvc_Micro, handle) {
 			ZEPHIR_INIT_NVAR(&before);
 			ZEPHIR_CALL_METHOD(&params, &router, "getparams", NULL, 0);
 			zephir_check_call_status_or_jump(try_end_1);
-			zephir_read_property(&_16$$7, this_ptr, SL("modelBinder"), PH_NOISY_CC | PH_READONLY);
+			zephir_read_property(&_16$$7, this_ptr, ZEND_STRL("modelBinder"), PH_NOISY_CC | PH_READONLY);
 			ZEPHIR_CPY_WRT(&modelBinder, &_16$$7);
 			_27$$7 = Z_TYPE_P(&handler) == IS_OBJECT;
 			if (_27$$7) {
@@ -883,14 +883,14 @@ PHP_METHOD(Phalcon_Mvc_Micro, handle) {
 			}
 			if (Z_TYPE_P(&handler) == IS_ARRAY) {
 				ZEPHIR_OBS_NVAR(&realHandler);
-				zephir_array_fetch_long(&realHandler, &handler, 0, PH_NOISY, "/home/nikos/Work/niden/cphalcon/phalcon/Mvc/Micro.zep", 494);
+				zephir_array_fetch_long(&realHandler, &handler, 0, PH_NOISY, "phalcon/Mvc/Micro.zep", 494);
 				_34$$25 = zephir_instance_of_ev(&realHandler, phalcon_mvc_controller_ce);
 				if (_34$$25) {
 					_34$$25 = Z_TYPE_P(&modelBinder) != IS_NULL;
 				}
 				if (_34$$25) {
 					ZEPHIR_OBS_VAR(&methodName);
-					zephir_array_fetch_long(&methodName, &handler, 1, PH_NOISY, "/home/nikos/Work/niden/cphalcon/phalcon/Mvc/Micro.zep", 497);
+					zephir_array_fetch_long(&methodName, &handler, 1, PH_NOISY, "phalcon/Mvc/Micro.zep", 497);
 					ZEPHIR_INIT_VAR(&_35$$26);
 					zephir_get_class(&_35$$26, &realHandler, 0);
 					ZEPHIR_INIT_VAR(&_36$$26);
@@ -907,7 +907,7 @@ PHP_METHOD(Phalcon_Mvc_Micro, handle) {
 			}
 			if (_38$$7) {
 				ZEPHIR_OBS_NVAR(&methodName);
-				zephir_array_fetch_long(&methodName, &handler, 1, PH_NOISY, "/home/nikos/Work/niden/cphalcon/phalcon/Mvc/Micro.zep", 514);
+				zephir_array_fetch_long(&methodName, &handler, 1, PH_NOISY, "phalcon/Mvc/Micro.zep", 514);
 				ZEPHIR_CALL_METHOD(&lazyReturned, &realHandler, "callmethod", NULL, 0, &methodName, &params, &modelBinder);
 				zephir_check_call_status_or_jump(try_end_1);
 			} else {
@@ -925,14 +925,14 @@ PHP_METHOD(Phalcon_Mvc_Micro, handle) {
 					RETURN_MM_BOOL(0);
 				}
 			}
-			zephir_read_property(&_16$$7, this_ptr, SL("afterBindingHandlers"), PH_NOISY_CC | PH_READONLY);
+			zephir_read_property(&_16$$7, this_ptr, ZEND_STRL("afterBindingHandlers"), PH_NOISY_CC | PH_READONLY);
 			ZEPHIR_CPY_WRT(&afterBindingHandlers, &_16$$7);
 			if (0) {
-				zephir_update_property_zval(this_ptr, SL("stopped"), &__$true);
+				zephir_update_property_zval(this_ptr, ZEND_STRL("stopped"), &__$true);
 			} else {
-				zephir_update_property_zval(this_ptr, SL("stopped"), &__$false);
+				zephir_update_property_zval(this_ptr, ZEND_STRL("stopped"), &__$false);
 			}
-			zephir_is_iterable(&afterBindingHandlers, 0, "/home/nikos/Work/niden/cphalcon/phalcon/Mvc/Micro.zep", 577);
+			zephir_is_iterable(&afterBindingHandlers, 0, "phalcon/Mvc/Micro.zep", 577);
 			if (Z_TYPE_P(&afterBindingHandlers) == IS_ARRAY) {
 				ZEND_HASH_FOREACH_VAL(Z_ARRVAL_P(&afterBindingHandlers), _41$$7)
 				{
@@ -951,9 +951,9 @@ PHP_METHOD(Phalcon_Mvc_Micro, handle) {
 							object_init_ex(&_44$$34, phalcon_mvc_micro_exception_ce);
 							ZEPHIR_INIT_NVAR(&_45$$34);
 							ZVAL_STRING(&_45$$34, "'afterBinding' handler is not callable");
-							ZEPHIR_CALL_METHOD(NULL, &_44$$34, "__construct", NULL, 6, &_45$$34);
+							ZEPHIR_CALL_METHOD(NULL, &_44$$34, "__construct", NULL, 8, &_45$$34);
 							zephir_check_call_status_or_jump(try_end_1);
-							zephir_throw_exception_debug(&_44$$34, "/home/nikos/Work/niden/cphalcon/phalcon/Mvc/Micro.zep", 557);
+							zephir_throw_exception_debug(&_44$$34, "phalcon/Mvc/Micro.zep", 557);
 							goto try_end_1;
 
 						}
@@ -961,7 +961,7 @@ PHP_METHOD(Phalcon_Mvc_Micro, handle) {
 						ZEPHIR_CALL_USER_FUNC(&status, &afterBinding);
 						zephir_check_call_status_or_jump(try_end_1);
 					}
-					zephir_read_property(&_46$$31, this_ptr, SL("stopped"), PH_NOISY_CC | PH_READONLY);
+					zephir_read_property(&_46$$31, this_ptr, ZEND_STRL("stopped"), PH_NOISY_CC | PH_READONLY);
 					if (zephir_is_true(&_46$$31)) {
 						RETURN_CCTOR(&status);
 					}
@@ -990,9 +990,9 @@ PHP_METHOD(Phalcon_Mvc_Micro, handle) {
 								object_init_ex(&_48$$39, phalcon_mvc_micro_exception_ce);
 								ZEPHIR_INIT_NVAR(&_49$$39);
 								ZVAL_STRING(&_49$$39, "'afterBinding' handler is not callable");
-								ZEPHIR_CALL_METHOD(NULL, &_48$$39, "__construct", NULL, 6, &_49$$39);
+								ZEPHIR_CALL_METHOD(NULL, &_48$$39, "__construct", NULL, 8, &_49$$39);
 								zephir_check_call_status_or_jump(try_end_1);
-								zephir_throw_exception_debug(&_48$$39, "/home/nikos/Work/niden/cphalcon/phalcon/Mvc/Micro.zep", 557);
+								zephir_throw_exception_debug(&_48$$39, "phalcon/Mvc/Micro.zep", 557);
 								goto try_end_1;
 
 							}
@@ -1000,7 +1000,7 @@ PHP_METHOD(Phalcon_Mvc_Micro, handle) {
 							ZEPHIR_CALL_USER_FUNC(&status, &afterBinding);
 							zephir_check_call_status_or_jump(try_end_1);
 						}
-						zephir_read_property(&_50$$36, this_ptr, SL("stopped"), PH_NOISY_CC | PH_READONLY);
+						zephir_read_property(&_50$$36, this_ptr, ZEND_STRL("stopped"), PH_NOISY_CC | PH_READONLY);
 						if (zephir_is_true(&_50$$36)) {
 							RETURN_CCTOR(&status);
 						}
@@ -1009,21 +1009,21 @@ PHP_METHOD(Phalcon_Mvc_Micro, handle) {
 				}
 			}
 			ZEPHIR_INIT_NVAR(&afterBinding);
-			zephir_update_property_zval(this_ptr, SL("returnedValue"), &returnedValue);
+			zephir_update_property_zval(this_ptr, ZEND_STRL("returnedValue"), &returnedValue);
 			if (Z_TYPE_P(&eventsManager) == IS_OBJECT) {
 				ZEPHIR_INIT_VAR(&_51$$41);
 				ZVAL_STRING(&_51$$41, "micro:afterExecuteRoute");
 				ZEPHIR_CALL_METHOD(NULL, &eventsManager, "fire", NULL, 0, &_51$$41, this_ptr);
 				zephir_check_call_status_or_jump(try_end_1);
 			}
-			zephir_read_property(&_16$$7, this_ptr, SL("afterHandlers"), PH_NOISY_CC | PH_READONLY);
+			zephir_read_property(&_16$$7, this_ptr, ZEND_STRL("afterHandlers"), PH_NOISY_CC | PH_READONLY);
 			ZEPHIR_CPY_WRT(&afterHandlers, &_16$$7);
 			if (0) {
-				zephir_update_property_zval(this_ptr, SL("stopped"), &__$true);
+				zephir_update_property_zval(this_ptr, ZEND_STRL("stopped"), &__$true);
 			} else {
-				zephir_update_property_zval(this_ptr, SL("stopped"), &__$false);
+				zephir_update_property_zval(this_ptr, ZEND_STRL("stopped"), &__$false);
 			}
-			zephir_is_iterable(&afterHandlers, 0, "/home/nikos/Work/niden/cphalcon/phalcon/Mvc/Micro.zep", 616);
+			zephir_is_iterable(&afterHandlers, 0, "phalcon/Mvc/Micro.zep", 616);
 			if (Z_TYPE_P(&afterHandlers) == IS_ARRAY) {
 				ZEND_HASH_FOREACH_VAL(Z_ARRVAL_P(&afterHandlers), _52$$7)
 				{
@@ -1042,9 +1042,9 @@ PHP_METHOD(Phalcon_Mvc_Micro, handle) {
 							object_init_ex(&_55$$45, phalcon_mvc_micro_exception_ce);
 							ZEPHIR_INIT_NVAR(&_56$$45);
 							ZVAL_STRING(&_56$$45, "One of the 'after' handlers is not callable");
-							ZEPHIR_CALL_METHOD(NULL, &_55$$45, "__construct", NULL, 6, &_56$$45);
+							ZEPHIR_CALL_METHOD(NULL, &_55$$45, "__construct", NULL, 8, &_56$$45);
 							zephir_check_call_status_or_jump(try_end_1);
-							zephir_throw_exception_debug(&_55$$45, "/home/nikos/Work/niden/cphalcon/phalcon/Mvc/Micro.zep", 603);
+							zephir_throw_exception_debug(&_55$$45, "phalcon/Mvc/Micro.zep", 603);
 							goto try_end_1;
 
 						}
@@ -1052,7 +1052,7 @@ PHP_METHOD(Phalcon_Mvc_Micro, handle) {
 						ZEPHIR_CALL_USER_FUNC(&status, &after);
 						zephir_check_call_status_or_jump(try_end_1);
 					}
-					zephir_read_property(&_57$$42, this_ptr, SL("stopped"), PH_NOISY_CC | PH_READONLY);
+					zephir_read_property(&_57$$42, this_ptr, ZEND_STRL("stopped"), PH_NOISY_CC | PH_READONLY);
 					if (zephir_is_true(&_57$$42)) {
 						break;
 					}
@@ -1081,9 +1081,9 @@ PHP_METHOD(Phalcon_Mvc_Micro, handle) {
 								object_init_ex(&_59$$50, phalcon_mvc_micro_exception_ce);
 								ZEPHIR_INIT_NVAR(&_60$$50);
 								ZVAL_STRING(&_60$$50, "One of the 'after' handlers is not callable");
-								ZEPHIR_CALL_METHOD(NULL, &_59$$50, "__construct", NULL, 6, &_60$$50);
+								ZEPHIR_CALL_METHOD(NULL, &_59$$50, "__construct", NULL, 8, &_60$$50);
 								zephir_check_call_status_or_jump(try_end_1);
-								zephir_throw_exception_debug(&_59$$50, "/home/nikos/Work/niden/cphalcon/phalcon/Mvc/Micro.zep", 603);
+								zephir_throw_exception_debug(&_59$$50, "phalcon/Mvc/Micro.zep", 603);
 								goto try_end_1;
 
 							}
@@ -1091,7 +1091,7 @@ PHP_METHOD(Phalcon_Mvc_Micro, handle) {
 							ZEPHIR_CALL_USER_FUNC(&status, &after);
 							zephir_check_call_status_or_jump(try_end_1);
 						}
-						zephir_read_property(&_61$$47, this_ptr, SL("stopped"), PH_NOISY_CC | PH_READONLY);
+						zephir_read_property(&_61$$47, this_ptr, ZEND_STRL("stopped"), PH_NOISY_CC | PH_READONLY);
 						if (zephir_is_true(&_61$$47)) {
 							break;
 						}
@@ -1101,7 +1101,7 @@ PHP_METHOD(Phalcon_Mvc_Micro, handle) {
 			}
 			ZEPHIR_INIT_NVAR(&after);
 		} else {
-			zephir_read_property(&_62$$52, this_ptr, SL("eventsManager"), PH_NOISY_CC | PH_READONLY);
+			zephir_read_property(&_62$$52, this_ptr, ZEND_STRL("eventsManager"), PH_NOISY_CC | PH_READONLY);
 			ZEPHIR_CPY_WRT(&eventsManager, &_62$$52);
 			if (Z_TYPE_P(&eventsManager) == IS_OBJECT) {
 				ZEPHIR_INIT_VAR(&_64$$53);
@@ -1112,16 +1112,16 @@ PHP_METHOD(Phalcon_Mvc_Micro, handle) {
 					RETURN_MM_BOOL(0);
 				}
 			}
-			zephir_read_property(&_62$$52, this_ptr, SL("notFoundHandler"), PH_NOISY_CC | PH_READONLY);
+			zephir_read_property(&_62$$52, this_ptr, ZEND_STRL("notFoundHandler"), PH_NOISY_CC | PH_READONLY);
 			ZEPHIR_CPY_WRT(&notFoundHandler, &_62$$52);
 			if (UNEXPECTED(!(zephir_is_callable(&notFoundHandler)))) {
 				ZEPHIR_INIT_VAR(&_65$$55);
 				object_init_ex(&_65$$55, phalcon_mvc_micro_exception_ce);
 				ZEPHIR_INIT_VAR(&_66$$55);
 				ZVAL_STRING(&_66$$55, "Not-Found handler is not callable or is not defined");
-				ZEPHIR_CALL_METHOD(NULL, &_65$$55, "__construct", NULL, 6, &_66$$55);
+				ZEPHIR_CALL_METHOD(NULL, &_65$$55, "__construct", NULL, 8, &_66$$55);
 				zephir_check_call_status_or_jump(try_end_1);
-				zephir_throw_exception_debug(&_65$$55, "/home/nikos/Work/niden/cphalcon/phalcon/Mvc/Micro.zep", 636);
+				zephir_throw_exception_debug(&_65$$55, "phalcon/Mvc/Micro.zep", 636);
 				goto try_end_1;
 
 			}
@@ -1135,14 +1135,14 @@ PHP_METHOD(Phalcon_Mvc_Micro, handle) {
 			ZEPHIR_CALL_METHOD(NULL, &eventsManager, "fire", NULL, 0, &_67$$56, this_ptr, &returnedValue);
 			zephir_check_call_status_or_jump(try_end_1);
 		}
-		zephir_read_property(&_5$$4, this_ptr, SL("finishHandlers"), PH_NOISY_CC | PH_READONLY);
+		zephir_read_property(&_5$$4, this_ptr, ZEND_STRL("finishHandlers"), PH_NOISY_CC | PH_READONLY);
 		ZEPHIR_CPY_WRT(&finishHandlers, &_5$$4);
 		if (0) {
-			zephir_update_property_zval(this_ptr, SL("stopped"), &__$true);
+			zephir_update_property_zval(this_ptr, ZEND_STRL("stopped"), &__$true);
 		} else {
-			zephir_update_property_zval(this_ptr, SL("stopped"), &__$false);
+			zephir_update_property_zval(this_ptr, ZEND_STRL("stopped"), &__$false);
 		}
-		zephir_is_iterable(&finishHandlers, 0, "/home/nikos/Work/niden/cphalcon/phalcon/Mvc/Micro.zep", 691);
+		zephir_is_iterable(&finishHandlers, 0, "phalcon/Mvc/Micro.zep", 691);
 		if (Z_TYPE_P(&finishHandlers) == IS_ARRAY) {
 			ZEND_HASH_FOREACH_VAL(Z_ARRVAL_P(&finishHandlers), _68$$4)
 			{
@@ -1161,9 +1161,9 @@ PHP_METHOD(Phalcon_Mvc_Micro, handle) {
 						object_init_ex(&_71$$60, phalcon_mvc_micro_exception_ce);
 						ZEPHIR_INIT_NVAR(&_72$$60);
 						ZVAL_STRING(&_72$$60, "One of the 'finish' handlers is not callable");
-						ZEPHIR_CALL_METHOD(NULL, &_71$$60, "__construct", NULL, 6, &_72$$60);
+						ZEPHIR_CALL_METHOD(NULL, &_71$$60, "__construct", NULL, 8, &_72$$60);
 						zephir_check_call_status_or_jump(try_end_1);
-						zephir_throw_exception_debug(&_71$$60, "/home/nikos/Work/niden/cphalcon/phalcon/Mvc/Micro.zep", 672);
+						zephir_throw_exception_debug(&_71$$60, "phalcon/Mvc/Micro.zep", 672);
 						goto try_end_1;
 
 					}
@@ -1174,7 +1174,7 @@ PHP_METHOD(Phalcon_Mvc_Micro, handle) {
 					ZEPHIR_CALL_USER_FUNC_ARRAY(&status, &finish, &_73$$59);
 					zephir_check_call_status_or_jump(try_end_1);
 				}
-				zephir_read_property(&_74$$57, this_ptr, SL("stopped"), PH_NOISY_CC | PH_READONLY);
+				zephir_read_property(&_74$$57, this_ptr, ZEND_STRL("stopped"), PH_NOISY_CC | PH_READONLY);
 				if (zephir_is_true(&_74$$57)) {
 					break;
 				}
@@ -1203,9 +1203,9 @@ PHP_METHOD(Phalcon_Mvc_Micro, handle) {
 							object_init_ex(&_76$$65, phalcon_mvc_micro_exception_ce);
 							ZEPHIR_INIT_NVAR(&_77$$65);
 							ZVAL_STRING(&_77$$65, "One of the 'finish' handlers is not callable");
-							ZEPHIR_CALL_METHOD(NULL, &_76$$65, "__construct", NULL, 6, &_77$$65);
+							ZEPHIR_CALL_METHOD(NULL, &_76$$65, "__construct", NULL, 8, &_77$$65);
 							zephir_check_call_status_or_jump(try_end_1);
-							zephir_throw_exception_debug(&_76$$65, "/home/nikos/Work/niden/cphalcon/phalcon/Mvc/Micro.zep", 672);
+							zephir_throw_exception_debug(&_76$$65, "phalcon/Mvc/Micro.zep", 672);
 							goto try_end_1;
 
 						}
@@ -1216,7 +1216,7 @@ PHP_METHOD(Phalcon_Mvc_Micro, handle) {
 						ZEPHIR_CALL_USER_FUNC_ARRAY(&status, &finish, &_78$$64);
 						zephir_check_call_status_or_jump(try_end_1);
 					}
-					zephir_read_property(&_79$$62, this_ptr, SL("stopped"), PH_NOISY_CC | PH_READONLY);
+					zephir_read_property(&_79$$62, this_ptr, ZEND_STRL("stopped"), PH_NOISY_CC | PH_READONLY);
 					if (zephir_is_true(&_79$$62)) {
 						break;
 					}
@@ -1235,7 +1235,7 @@ PHP_METHOD(Phalcon_Mvc_Micro, handle) {
 		if (zephir_is_instance_of(&_80, SL("Throwable"))) {
 			zend_clear_exception(TSRMLS_C);
 			ZEPHIR_CPY_WRT(&e, &_80);
-			zephir_read_property(&_81$$67, this_ptr, SL("eventsManager"), PH_NOISY_CC | PH_READONLY);
+			zephir_read_property(&_81$$67, this_ptr, ZEND_STRL("eventsManager"), PH_NOISY_CC | PH_READONLY);
 			ZEPHIR_CPY_WRT(&eventsManager, &_81$$67);
 			if (Z_TYPE_P(&eventsManager) == IS_OBJECT) {
 				ZEPHIR_INIT_VAR(&_82$$68);
@@ -1243,11 +1243,11 @@ PHP_METHOD(Phalcon_Mvc_Micro, handle) {
 				ZEPHIR_CALL_METHOD(&returnedValue, &eventsManager, "fire", NULL, 0, &_82$$68, this_ptr, &e);
 				zephir_check_call_status();
 			}
-			zephir_read_property(&_81$$67, this_ptr, SL("errorHandler"), PH_NOISY_CC | PH_READONLY);
+			zephir_read_property(&_81$$67, this_ptr, ZEND_STRL("errorHandler"), PH_NOISY_CC | PH_READONLY);
 			ZEPHIR_CPY_WRT(&errorHandler, &_81$$67);
 			if (zephir_is_true(&errorHandler)) {
 				if (UNEXPECTED(!(zephir_is_callable(&errorHandler)))) {
-					ZEPHIR_THROW_EXCEPTION_DEBUG_STR(phalcon_mvc_micro_exception_ce, "Error handler is not callable", "/home/nikos/Work/niden/cphalcon/phalcon/Mvc/Micro.zep", 712);
+					ZEPHIR_THROW_EXCEPTION_DEBUG_STR(phalcon_mvc_micro_exception_ce, "Error handler is not callable", "phalcon/Mvc/Micro.zep", 712);
 					return;
 				}
 				ZEPHIR_INIT_VAR(&_83$$69);
@@ -1258,34 +1258,34 @@ PHP_METHOD(Phalcon_Mvc_Micro, handle) {
 				zephir_check_call_status();
 				if (Z_TYPE_P(&returnedValue) == IS_OBJECT) {
 					if (!(zephir_instance_of_ev(&returnedValue, phalcon_http_responseinterface_ce))) {
-						zephir_throw_exception_debug(&e, "/home/nikos/Work/niden/cphalcon/phalcon/Mvc/Micro.zep", 725);
+						zephir_throw_exception_debug(&e, "phalcon/Mvc/Micro.zep", 725);
 						ZEPHIR_MM_RESTORE();
 						return;
 					}
 				} else {
 					if (!ZEPHIR_IS_FALSE_IDENTICAL(&returnedValue)) {
-						zephir_throw_exception_debug(&e, "/home/nikos/Work/niden/cphalcon/phalcon/Mvc/Micro.zep", 729);
+						zephir_throw_exception_debug(&e, "phalcon/Mvc/Micro.zep", 729);
 						ZEPHIR_MM_RESTORE();
 						return;
 					}
 				}
 			} else {
 				if (!ZEPHIR_IS_FALSE_IDENTICAL(&returnedValue)) {
-					zephir_throw_exception_debug(&e, "/home/nikos/Work/niden/cphalcon/phalcon/Mvc/Micro.zep", 734);
+					zephir_throw_exception_debug(&e, "phalcon/Mvc/Micro.zep", 734);
 					ZEPHIR_MM_RESTORE();
 					return;
 				}
 			}
 		}
 	}
-	zephir_read_property(&_0, this_ptr, SL("responseHandler"), PH_NOISY_CC | PH_READONLY);
+	zephir_read_property(&_0, this_ptr, ZEND_STRL("responseHandler"), PH_NOISY_CC | PH_READONLY);
 	if (zephir_is_true(&_0)) {
-		zephir_read_property(&_84$$77, this_ptr, SL("responseHandler"), PH_NOISY_CC | PH_READONLY);
+		zephir_read_property(&_84$$77, this_ptr, ZEND_STRL("responseHandler"), PH_NOISY_CC | PH_READONLY);
 		if (UNEXPECTED(!(zephir_is_callable(&_84$$77)))) {
-			ZEPHIR_THROW_EXCEPTION_DEBUG_STR(phalcon_mvc_micro_exception_ce, "Response handler is not callable or is not defined", "/home/nikos/Work/niden/cphalcon/phalcon/Mvc/Micro.zep", 747);
+			ZEPHIR_THROW_EXCEPTION_DEBUG_STR(phalcon_mvc_micro_exception_ce, "Response handler is not callable or is not defined", "phalcon/Mvc/Micro.zep", 747);
 			return;
 		}
-		zephir_read_property(&_85$$77, this_ptr, SL("responseHandler"), PH_NOISY_CC | PH_READONLY);
+		zephir_read_property(&_85$$77, this_ptr, ZEND_STRL("responseHandler"), PH_NOISY_CC | PH_READONLY);
 		ZEPHIR_INIT_NVAR(&returnedValue);
 		ZEPHIR_CALL_USER_FUNC(&returnedValue, &_85$$77);
 		zephir_check_call_status();
@@ -1352,16 +1352,16 @@ PHP_METHOD(Phalcon_Mvc_Micro, hasService) {
 	}
 
 
-	zephir_read_property(&_0, this_ptr, SL("container"), PH_NOISY_CC | PH_READONLY);
+	zephir_read_property(&_0, this_ptr, ZEND_STRL("container"), PH_NOISY_CC | PH_READONLY);
 	ZEPHIR_CPY_WRT(&container, &_0);
 	if (Z_TYPE_P(&container) != IS_OBJECT) {
 		ZEPHIR_INIT_NVAR(&container);
 		object_init_ex(&container, phalcon_di_factorydefault_ce);
-		ZEPHIR_CALL_METHOD(NULL, &container, "__construct", NULL, 420);
+		ZEPHIR_CALL_METHOD(NULL, &container, "__construct", NULL, 440);
 		zephir_check_call_status();
-		zephir_update_property_zval(this_ptr, SL("container"), &container);
+		zephir_update_property_zval(this_ptr, ZEND_STRL("container"), &container);
 	}
-	ZEPHIR_RETURN_CALL_METHOD(&container, "has", NULL, 423, &serviceName);
+	ZEPHIR_RETURN_CALL_METHOD(&container, "has", NULL, 443, &serviceName);
 	zephir_check_call_status();
 	RETURN_MM();
 
@@ -1494,13 +1494,13 @@ PHP_METHOD(Phalcon_Mvc_Micro, mount) {
 	ZEPHIR_CALL_METHOD(&mainHandler, collection, "gethandler", NULL, 0);
 	zephir_check_call_status();
 	if (UNEXPECTED(ZEPHIR_IS_EMPTY(&mainHandler))) {
-		ZEPHIR_THROW_EXCEPTION_DEBUG_STR(phalcon_mvc_micro_exception_ce, "Collection requires a main handler", "/home/nikos/Work/niden/cphalcon/phalcon/Mvc/Micro.zep", 870);
+		ZEPHIR_THROW_EXCEPTION_DEBUG_STR(phalcon_mvc_micro_exception_ce, "Collection requires a main handler", "phalcon/Mvc/Micro.zep", 870);
 		return;
 	}
 	ZEPHIR_CALL_METHOD(&handlers, collection, "gethandlers", NULL, 0);
 	zephir_check_call_status();
 	if (UNEXPECTED(!(zephir_fast_count_int(&handlers)))) {
-		ZEPHIR_THROW_EXCEPTION_DEBUG_STR(phalcon_mvc_micro_exception_ce, "There are no handlers to mount", "/home/nikos/Work/niden/cphalcon/phalcon/Mvc/Micro.zep", 876);
+		ZEPHIR_THROW_EXCEPTION_DEBUG_STR(phalcon_mvc_micro_exception_ce, "There are no handlers to mount", "phalcon/Mvc/Micro.zep", 876);
 		return;
 	}
 	ZEPHIR_CALL_METHOD(&_0, collection, "islazy", NULL, 0);
@@ -1508,31 +1508,31 @@ PHP_METHOD(Phalcon_Mvc_Micro, mount) {
 	if (zephir_is_true(&_0)) {
 		ZEPHIR_INIT_VAR(&lazyHandler);
 		object_init_ex(&lazyHandler, phalcon_mvc_micro_lazyloader_ce);
-		ZEPHIR_CALL_METHOD(NULL, &lazyHandler, "__construct", NULL, 424, &mainHandler);
+		ZEPHIR_CALL_METHOD(NULL, &lazyHandler, "__construct", NULL, 444, &mainHandler);
 		zephir_check_call_status();
 	} else {
 		ZEPHIR_CPY_WRT(&lazyHandler, &mainHandler);
 	}
 	ZEPHIR_CALL_METHOD(&prefix, collection, "getprefix", NULL, 0);
 	zephir_check_call_status();
-	zephir_is_iterable(&handlers, 0, "/home/nikos/Work/niden/cphalcon/phalcon/Mvc/Micro.zep", 934);
+	zephir_is_iterable(&handlers, 0, "phalcon/Mvc/Micro.zep", 934);
 	if (Z_TYPE_P(&handlers) == IS_ARRAY) {
 		ZEND_HASH_FOREACH_VAL(Z_ARRVAL_P(&handlers), _1)
 		{
 			ZEPHIR_INIT_NVAR(&handler);
 			ZVAL_COPY(&handler, _1);
 			if (UNEXPECTED(Z_TYPE_P(&handler) != IS_ARRAY)) {
-				ZEPHIR_THROW_EXCEPTION_DEBUG_STR(phalcon_mvc_micro_exception_ce, "One of the registered handlers is invalid", "/home/nikos/Work/niden/cphalcon/phalcon/Mvc/Micro.zep", 897);
+				ZEPHIR_THROW_EXCEPTION_DEBUG_STR(phalcon_mvc_micro_exception_ce, "One of the registered handlers is invalid", "phalcon/Mvc/Micro.zep", 897);
 				return;
 			}
 			ZEPHIR_OBS_NVAR(&methods);
-			zephir_array_fetch_long(&methods, &handler, 0, PH_NOISY, "/home/nikos/Work/niden/cphalcon/phalcon/Mvc/Micro.zep", 900);
+			zephir_array_fetch_long(&methods, &handler, 0, PH_NOISY, "phalcon/Mvc/Micro.zep", 900);
 			ZEPHIR_OBS_NVAR(&pattern);
-			zephir_array_fetch_long(&pattern, &handler, 1, PH_NOISY, "/home/nikos/Work/niden/cphalcon/phalcon/Mvc/Micro.zep", 901);
+			zephir_array_fetch_long(&pattern, &handler, 1, PH_NOISY, "phalcon/Mvc/Micro.zep", 901);
 			ZEPHIR_OBS_NVAR(&subHandler);
-			zephir_array_fetch_long(&subHandler, &handler, 2, PH_NOISY, "/home/nikos/Work/niden/cphalcon/phalcon/Mvc/Micro.zep", 902);
+			zephir_array_fetch_long(&subHandler, &handler, 2, PH_NOISY, "phalcon/Mvc/Micro.zep", 902);
 			ZEPHIR_OBS_NVAR(&name);
-			zephir_array_fetch_long(&name, &handler, 3, PH_NOISY, "/home/nikos/Work/niden/cphalcon/phalcon/Mvc/Micro.zep", 903);
+			zephir_array_fetch_long(&name, &handler, 3, PH_NOISY, "phalcon/Mvc/Micro.zep", 903);
 			ZEPHIR_INIT_NVAR(&realHandler);
 			zephir_create_array(&realHandler, 2, 0);
 			zephir_array_fast_append(&realHandler, &lazyHandler);
@@ -1578,17 +1578,17 @@ PHP_METHOD(Phalcon_Mvc_Micro, mount) {
 			ZEPHIR_CALL_METHOD(&handler, &handlers, "current", NULL, 0);
 			zephir_check_call_status();
 				if (UNEXPECTED(Z_TYPE_P(&handler) != IS_ARRAY)) {
-					ZEPHIR_THROW_EXCEPTION_DEBUG_STR(phalcon_mvc_micro_exception_ce, "One of the registered handlers is invalid", "/home/nikos/Work/niden/cphalcon/phalcon/Mvc/Micro.zep", 897);
+					ZEPHIR_THROW_EXCEPTION_DEBUG_STR(phalcon_mvc_micro_exception_ce, "One of the registered handlers is invalid", "phalcon/Mvc/Micro.zep", 897);
 					return;
 				}
 				ZEPHIR_OBS_NVAR(&methods);
-				zephir_array_fetch_long(&methods, &handler, 0, PH_NOISY, "/home/nikos/Work/niden/cphalcon/phalcon/Mvc/Micro.zep", 900);
+				zephir_array_fetch_long(&methods, &handler, 0, PH_NOISY, "phalcon/Mvc/Micro.zep", 900);
 				ZEPHIR_OBS_NVAR(&pattern);
-				zephir_array_fetch_long(&pattern, &handler, 1, PH_NOISY, "/home/nikos/Work/niden/cphalcon/phalcon/Mvc/Micro.zep", 901);
+				zephir_array_fetch_long(&pattern, &handler, 1, PH_NOISY, "phalcon/Mvc/Micro.zep", 901);
 				ZEPHIR_OBS_NVAR(&subHandler);
-				zephir_array_fetch_long(&subHandler, &handler, 2, PH_NOISY, "/home/nikos/Work/niden/cphalcon/phalcon/Mvc/Micro.zep", 902);
+				zephir_array_fetch_long(&subHandler, &handler, 2, PH_NOISY, "phalcon/Mvc/Micro.zep", 902);
 				ZEPHIR_OBS_NVAR(&name);
-				zephir_array_fetch_long(&name, &handler, 3, PH_NOISY, "/home/nikos/Work/niden/cphalcon/phalcon/Mvc/Micro.zep", 903);
+				zephir_array_fetch_long(&name, &handler, 3, PH_NOISY, "phalcon/Mvc/Micro.zep", 903);
 				ZEPHIR_INIT_NVAR(&_6$$15);
 				zephir_create_array(&_6$$15, 2, 0);
 				zephir_array_fast_append(&_6$$15, &lazyHandler);
@@ -1648,7 +1648,7 @@ PHP_METHOD(Phalcon_Mvc_Micro, notFound) {
 
 
 
-	zephir_update_property_zval(this_ptr, SL("notFoundHandler"), handler);
+	zephir_update_property_zval(this_ptr, ZEND_STRL("notFoundHandler"), handler);
 	RETURN_THISW();
 
 }
@@ -1756,16 +1756,16 @@ PHP_METHOD(Phalcon_Mvc_Micro, offsetUnset) {
 
 
 
-	zephir_read_property(&_0, this_ptr, SL("container"), PH_NOISY_CC | PH_READONLY);
+	zephir_read_property(&_0, this_ptr, ZEND_STRL("container"), PH_NOISY_CC | PH_READONLY);
 	ZEPHIR_CPY_WRT(&container, &_0);
 	if (Z_TYPE_P(&container) != IS_OBJECT) {
 		ZEPHIR_INIT_NVAR(&container);
 		object_init_ex(&container, phalcon_di_factorydefault_ce);
-		ZEPHIR_CALL_METHOD(NULL, &container, "__construct", NULL, 420);
+		ZEPHIR_CALL_METHOD(NULL, &container, "__construct", NULL, 440);
 		zephir_check_call_status();
-		zephir_update_property_zval(this_ptr, SL("container"), &container);
+		zephir_update_property_zval(this_ptr, ZEND_STRL("container"), &container);
 	}
-	ZEPHIR_CALL_METHOD(NULL, &container, "remove", NULL, 425, alias);
+	ZEPHIR_CALL_METHOD(NULL, &container, "remove", NULL, 445, alias);
 	zephir_check_call_status();
 	ZEPHIR_MM_RESTORE();
 
@@ -1967,7 +1967,7 @@ PHP_METHOD(Phalcon_Mvc_Micro, setActiveHandler) {
 
 
 
-	zephir_update_property_zval(this_ptr, SL("activeHandler"), activeHandler);
+	zephir_update_property_zval(this_ptr, ZEND_STRL("activeHandler"), activeHandler);
 
 }
 
@@ -2001,7 +2001,7 @@ PHP_METHOD(Phalcon_Mvc_Micro, setDI) {
 		ZEPHIR_CALL_METHOD(NULL, container, "set", NULL, 0, &_2$$3, this_ptr);
 		zephir_check_call_status();
 	}
-	zephir_update_property_zval(this_ptr, SL("container"), container);
+	zephir_update_property_zval(this_ptr, ZEND_STRL("container"), container);
 	ZEPHIR_MM_RESTORE();
 
 }
@@ -2050,7 +2050,7 @@ PHP_METHOD(Phalcon_Mvc_Micro, setModelBinder) {
 		ZEPHIR_CALL_METHOD(NULL, modelBinder, "setcache", NULL, 0, cache);
 		zephir_check_call_status();
 	}
-	zephir_update_property_zval(this_ptr, SL("modelBinder"), modelBinder);
+	zephir_update_property_zval(this_ptr, ZEND_STRL("modelBinder"), modelBinder);
 	RETURN_THIS();
 
 }
@@ -2072,7 +2072,7 @@ PHP_METHOD(Phalcon_Mvc_Micro, setResponseHandler) {
 
 
 
-	zephir_update_property_zval(this_ptr, SL("responseHandler"), handler);
+	zephir_update_property_zval(this_ptr, ZEND_STRL("responseHandler"), handler);
 	RETURN_THISW();
 
 }
@@ -2114,21 +2114,21 @@ PHP_METHOD(Phalcon_Mvc_Micro, setService) {
 	}
 
 
-	zephir_read_property(&_0, this_ptr, SL("container"), PH_NOISY_CC | PH_READONLY);
+	zephir_read_property(&_0, this_ptr, ZEND_STRL("container"), PH_NOISY_CC | PH_READONLY);
 	ZEPHIR_CPY_WRT(&container, &_0);
 	if (Z_TYPE_P(&container) != IS_OBJECT) {
 		ZEPHIR_INIT_NVAR(&container);
 		object_init_ex(&container, phalcon_di_factorydefault_ce);
-		ZEPHIR_CALL_METHOD(NULL, &container, "__construct", NULL, 420);
+		ZEPHIR_CALL_METHOD(NULL, &container, "__construct", NULL, 440);
 		zephir_check_call_status();
-		zephir_update_property_zval(this_ptr, SL("container"), &container);
+		zephir_update_property_zval(this_ptr, ZEND_STRL("container"), &container);
 	}
 	if (shared) {
 		ZVAL_BOOL(&_0, 1);
 	} else {
 		ZVAL_BOOL(&_0, 0);
 	}
-	ZEPHIR_RETURN_CALL_METHOD(&container, "set", NULL, 426, &serviceName, definition, &_0);
+	ZEPHIR_RETURN_CALL_METHOD(&container, "set", NULL, 446, &serviceName, definition, &_0);
 	zephir_check_call_status();
 	RETURN_MM();
 
@@ -2148,9 +2148,9 @@ PHP_METHOD(Phalcon_Mvc_Micro, stop) {
 
 
 	if (1) {
-		zephir_update_property_zval(this_ptr, SL("stopped"), &__$true);
+		zephir_update_property_zval(this_ptr, ZEND_STRL("stopped"), &__$true);
 	} else {
-		zephir_update_property_zval(this_ptr, SL("stopped"), &__$false);
+		zephir_update_property_zval(this_ptr, ZEND_STRL("stopped"), &__$false);
 	}
 
 }
@@ -2175,35 +2175,35 @@ zend_object *zephir_init_properties_Phalcon_Mvc_Micro(zend_class_entry *class_ty
 	{
 		zval local_this_ptr, *this_ptr = &local_this_ptr;
 		ZEPHIR_CREATE_OBJECT(this_ptr, class_type);
-		zephir_read_property(&_0, this_ptr, SL("handlers"), PH_NOISY_CC | PH_READONLY);
+		zephir_read_property_ex(&_0, this_ptr, ZEND_STRL("handlers"), PH_NOISY_CC | PH_READONLY);
 		if (Z_TYPE_P(&_0) == IS_NULL) {
 			ZEPHIR_INIT_VAR(&_1$$3);
 			array_init(&_1$$3);
-			zephir_update_property_zval(this_ptr, SL("handlers"), &_1$$3);
+			zephir_update_property_zval_ex(this_ptr, ZEND_STRL("handlers"), &_1$$3);
 		}
-		zephir_read_property(&_2, this_ptr, SL("finishHandlers"), PH_NOISY_CC | PH_READONLY);
+		zephir_read_property_ex(&_2, this_ptr, ZEND_STRL("finishHandlers"), PH_NOISY_CC | PH_READONLY);
 		if (Z_TYPE_P(&_2) == IS_NULL) {
 			ZEPHIR_INIT_VAR(&_3$$4);
 			array_init(&_3$$4);
-			zephir_update_property_zval(this_ptr, SL("finishHandlers"), &_3$$4);
+			zephir_update_property_zval_ex(this_ptr, ZEND_STRL("finishHandlers"), &_3$$4);
 		}
-		zephir_read_property(&_4, this_ptr, SL("beforeHandlers"), PH_NOISY_CC | PH_READONLY);
+		zephir_read_property_ex(&_4, this_ptr, ZEND_STRL("beforeHandlers"), PH_NOISY_CC | PH_READONLY);
 		if (Z_TYPE_P(&_4) == IS_NULL) {
 			ZEPHIR_INIT_VAR(&_5$$5);
 			array_init(&_5$$5);
-			zephir_update_property_zval(this_ptr, SL("beforeHandlers"), &_5$$5);
+			zephir_update_property_zval_ex(this_ptr, ZEND_STRL("beforeHandlers"), &_5$$5);
 		}
-		zephir_read_property(&_6, this_ptr, SL("afterHandlers"), PH_NOISY_CC | PH_READONLY);
+		zephir_read_property_ex(&_6, this_ptr, ZEND_STRL("afterHandlers"), PH_NOISY_CC | PH_READONLY);
 		if (Z_TYPE_P(&_6) == IS_NULL) {
 			ZEPHIR_INIT_VAR(&_7$$6);
 			array_init(&_7$$6);
-			zephir_update_property_zval(this_ptr, SL("afterHandlers"), &_7$$6);
+			zephir_update_property_zval_ex(this_ptr, ZEND_STRL("afterHandlers"), &_7$$6);
 		}
-		zephir_read_property(&_8, this_ptr, SL("afterBindingHandlers"), PH_NOISY_CC | PH_READONLY);
+		zephir_read_property_ex(&_8, this_ptr, ZEND_STRL("afterBindingHandlers"), PH_NOISY_CC | PH_READONLY);
 		if (Z_TYPE_P(&_8) == IS_NULL) {
 			ZEPHIR_INIT_VAR(&_9$$7);
 			array_init(&_9$$7);
-			zephir_update_property_zval(this_ptr, SL("afterBindingHandlers"), &_9$$7);
+			zephir_update_property_zval_ex(this_ptr, ZEND_STRL("afterBindingHandlers"), &_9$$7);
 		}
 		ZEPHIR_MM_RESTORE();
 		return Z_OBJ_P(this_ptr);
