@@ -16,7 +16,7 @@ namespace Phalcon\Test\Integration\Storage\Adapter\Apcu;
 use Phalcon\Storage\Adapter\Apcu;
 use Phalcon\Storage\SerializerFactory;
 use Phalcon\Test\Fixtures\Traits\ApcuTrait;
-use UnitTester;
+use IntegrationTester;
 
 class HasCest
 {
@@ -28,7 +28,7 @@ class HasCest
      * @author Phalcon Team <team@phalcon.io>
      * @since  2019-03-31
      */
-    public function storageAdapterApcuGetSetHas(UnitTester $I)
+    public function storageAdapterApcuGetSetHas(IntegrationTester $I)
     {
         $I->wantToTest('Storage\Adapter\Apcu - has()');
 
