@@ -14,7 +14,7 @@ declare(strict_types=1);
 namespace Phalcon\Test\Integration\Storage\Serializer\Json;
 
 use Phalcon\Storage\Serializer\Json;
-use UnitTester;
+use IntegrationTester;
 
 class SetDataCest
 {
@@ -24,7 +24,7 @@ class SetDataCest
      * @author Phalcon Team <team@phalcon.io>
      * @since  2019-03-30
      */
-    public function storageSerializerJsonSetData(UnitTester $I)
+    public function storageSerializerJsonSetData(IntegrationTester $I)
     {
         $I->wantToTest('Storage\Serializer\Json - setData()');
         $data       = ['Phalcon Framework'];
